Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( GDDirSuffix = ".gd" PathSeparator = fmt.Sprintf("%c", os.PathSeparator) ErrNoDriveContext = errors.New("no drive context found; run `drive init` or go into one of the directories (sub directories) that you performed `drive init`") )
Functions ¶
func IndicesAbsPath ¶
func LeastNonExistantRoot ¶
Types ¶
type Context ¶
type Context struct {
ClientId string `json:"client_id"`
ClientSecret string `json:"client_secret"`
RefreshToken string `json:"refresh_token"`
AbsPath string `json:"-"`
}
func Discover ¶
Discovers the gd directory, if no gd directory or credentials could be found for the path, returns ErrNoContext.
func Initialize ¶
func (*Context) DeserializeIndex ¶
func (*Context) SerializeIndex ¶
type Mount ¶
type Mount struct {
CreatedMountDir string
ShortestMountRoot string
Points []*MountPoint
}
type MountPoint ¶
func (*MountPoint) Unmount ¶
func (mpt *MountPoint) Unmount() error
Click to show internal directories.
Click to hide internal directories.